@@ -2,13 +2,19 @@
 
 #include "ast.h"
 
+#include <algorithm>
 #include <array>
+#include <cstdarg>
+#include <cstdlib>
+#include <string>
 
 #include "common.h"
+#include "enum_map.h"
 #include "flog.h"
 #include "parse_constants.h"
 #include "parse_tree.h"
-#include "wutil.h"
+#include "tokenizer.h"
+#include "wutil.h"  // IWYU pragma: keep
 
 namespace {
 
@@ -132,7 +138,7 @@ class token_stream_t {
         return result;
     }
 
-    /// Provide the orignal source code.
+    /// Provide the original source code.
     const wcstring &source() const { return src_; }
 
    private:
@@ -188,7 +194,7 @@ class token_stream_t {
             // Skip invalid tokens that have a zero length, especially if they are at EOF.
             if (subtoken_offset < result.source_length) {
                 result.source_start += subtoken_offset;
-                result.source_length -= subtoken_offset;
+                result.source_length = token.error_length;
             }
         }
 
@@ -344,6 +350,7 @@ struct source_range_visitor_t {
                 total.length = end - total.start;
             }
         }
+        return;
     }
 
     // Other node types recurse.
@@ -1076,7 +1083,7 @@ struct populator_t {
         const auto &tok = peek_token(1);
         if (tok.keyword == parse_keyword_t::kw_and || tok.keyword == parse_keyword_t::kw_or) {
             const wchar_t *cmdname = (tok.keyword == parse_keyword_t::kw_and ? L"and" : L"or");
-            parse_error(tok, parse_error_andor_in_pipeline, EXEC_ERR_MSG, cmdname);
+            parse_error(tok, parse_error_andor_in_pipeline, INVALID_PIPELINE_CMD_ERR_MSG, cmdname);
         }
         node.accept(*this);
     }
@@ -1086,6 +1093,7 @@ struct populator_t {
     enable_if_t<Node::Category == category_t::branch> visit_node_field(Node &node) {
         // This field is a direct embedding of an AST value.
         node.accept(*this);
+        return;
     }
 
     // Overload for token fields.
